<?php
/**
 * Chinese(Traditional) language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     chinsan <chinsan@mail2000.com.tw>
 */

$lang['admin_acl']  = '設定 ACL 存取名單';
$lang['acl_group']  = '群組';
$lang['acl_user']   = '帳號';
$lang['acl_perms']  = '設定權限於';
$lang['page']       = 'Page';
$lang['namespace']  = 'Namespace';

$lang['acl_perm1']  = '讀取權限';
$lang['acl_perm2']  = '編輯頁面';
$lang['acl_perm4']  = '新增頁面';
$lang['acl_perm8']  = '上傳圖檔';
$lang['acl_perm16'] = '刪除檔案';
$lang['acl_new']    = '新增管理規則';

//Setup VIM: ex: et ts=2 enc=utf-8 :
